@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: common.h,v 1.14 2004/07/26 00:28:50 oliv__a Exp $ */
+/* $Id: common.h,v 1.17 2010/04/19 20:14:11 oliv__a Exp $ */
 
 #ifndef _COMMON_H_
 #define _COMMON_H_
@@ -32,6 +32,8 @@
 #include <caml/bigarray.h>
 #include <caml/custom.h>
 
+#define UString_val(v) ((unsigned char *) Bp_val(v))
+
 /*
   Caml list manipulations
 
@@ -40,12 +42,12 @@
 */
 
 #define nil()      Val_emptylist
-extern value cons(value x,value l);
+extern value mlsdl_cons(value x,value l);
 #define is_nil     Is_long
 #define is_not_nil Is_block
 #define hd(v)      Field((v), 0)
 #define tl(v)      Field((v), 1)
-extern int list_length(value l);
+extern int mlsdl_list_length(value l);
 
 
 /* 
