@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: sdlevent_stub.c,v 1.24 2011/04/10 15:33:52 oliv__a Exp $ */
+/* $Id: sdlevent_stub.c,v 1.27 2012/07/03 19:11:45 oliv__a Exp $ */
 
 #include <SDL.h>
 
@@ -61,7 +61,8 @@ static Uint8 state_of_value(value l)
 {
   Uint8 state = 0;
   while(is_not_nil(l)){
-    state |= 1 << Int_val(hd(l));
+    if (Is_long(hd(l)))
+      state |= 1 << Int_val(hd(l));
     l = tl(l);
   }
   return state;
@@ -100,8 +101,8 @@ static value value_of_keyevent(SDL_KeyboardEvent keyevt)
   Field(r, 1) = keyevt.state == SDL_RELEASED ? Val_int(0) : Val_int(1);
   Field(r, 2) = find_mlsdl_keysym(keyevt.keysym.sym) ;
   Field(r, 3) = Val_int(keyevt.keysym.mod) ;
-  if (SDL_EnableUNICODE(-1) && keyevt.keysym.unicode <= 0xFF)
-    char_code = keyevt.keysym.unicode & 0xFF;
+  if (keyevt.keysym.unicode <= 0x7F)
+    char_code = keyevt.keysym.unicode;
   Field(r, 4) = Val_int(char_code);
   Field(r, 5) = Val_long(keyevt.keysym.unicode);
   tag = keyevt.state == SDL_PRESSED ? 1 : 2 ;
@@ -114,7 +115,7 @@ static value value_of_mouse_button(Uint8 b)
 {
   value r;
   if (SDL_BUTTON_LEFT <= b && b <= SDL_BUTTON_WHEELDOWN)
-    r = Val_int(b);
+    r = Val_int(b - 1);
   else {
     r = caml_alloc_small(1, 0);
     Field(r, 0) = Val_int(b);
@@ -177,7 +178,7 @@ static value value_of_SDLEvent(SDL_Event evt)
     r = alloc_small(4, 0);
     Field(r, 0) = Val_int(evt.jball.which);
     Field(r, 1) = Val_int(evt.jball.ball);
-    Field(r, 3) = Val_int(evt.jball.xrel);
+    Field(r, 2) = Val_int(evt.jball.xrel);
     Field(r, 3) = Val_int(evt.jball.yrel);
     v = alloc_small(1, 7);
     Field(v, 0) = r;
