@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: sdlloader_stub.c,v 1.15 2004/02/04 12:00:22 oliv__a Exp $ */
+/* $Id: sdlloader_stub.c,v 1.17 2010/04/19 20:25:54 oliv__a Exp $ */
 
 #include <string.h>
 
@@ -46,7 +46,12 @@ sdlloader_raise_exception (char *msg)
 
 CAMLprim value ml_IMG_Load(value file)
 {
-  SDL_Surface *s = IMG_Load(String_val(file));
+  SDL_Surface *s;
+  char *fname = strdup(String_val(file));
+  enter_blocking_section();
+  s = IMG_Load(fname);
+  leave_blocking_section();
+  free(fname);
   if(! s)
     sdlloader_raise_exception(IMG_GetError());
   return ML_SURFACE(s);
@@ -61,7 +66,7 @@ CAMLprim value ml_IMG_Load_RW(value o_autoclose, value rwops)
   return ML_SURFACE(s);
 }
 
-#if (SDL_IMAGE_VERSION >= 121)
+#if (OCAMLSDL_IMAGE_VERSION >= 121)
 CAMLprim value ml_IMG_ReadXPMFromArray(value string_arr)
 {
   int len = Wosize_val(string_arr);
