@@ -17,11 +17,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: sdltimer_stub.c,v 1.10 2002/11/21 11:01:17 oliv__a Exp $ */
+/* $Id: sdltimer_stub.c,v 1.11 2003/11/16 14:26:38 oliv__a Exp $ */
 
-#include <caml/callback.h>
-#include <caml/fail.h>
-#include <caml/mlvalues.h>
 #include <SDL.h>
 
 #include "common.h"
