@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: sdlttf_stub.c,v 1.27 2004/07/26 01:31:45 oliv__a Exp $ */
+/* $Id: sdlttf_stub.c,v 1.30 2010/04/19 20:14:11 oliv__a Exp $ */
 
 #include <SDL_ttf.h>
 
@@ -113,7 +113,7 @@ sdlttf_open_font(value file, value index, value ptsize)
   int c_index = Opt_arg(index, Int_val, 0);
   TTF_Font *font=NULL;
 
-#if (SDL_TTF_VERSION >= 204)
+#if (OCAMLSDL_TTF_VERSION >= 204)
   font = TTF_OpenFontIndex(String_val(file), Int_val(ptsize), c_index);
 #else  /* try to keep compatibility with SDL_ttf v1 */
   font = TTF_OpenFont(String_val(file), Int_val(ptsize));
@@ -130,7 +130,7 @@ sdlttf_get_font_style(value font)
 {
   int style = TTF_GetFontStyle(SDL_FONT(font));
   if (style == TTF_STYLE_NORMAL)
-    return cons(Val_int(0), Val_emptylist);
+    return mlsdl_cons(Val_int(0), Val_emptylist);
   else {
     int i;
     const int font_style_table [] = {
@@ -138,7 +138,7 @@ sdlttf_get_font_style(value font)
     value v_style = Val_emptylist;
     for(i=0; i < 3 ; i++)
       if(font_style_table[i] & style) 
-	v_style = cons(Val_int(i+1), v_style);
+	v_style = mlsdl_cons(Val_int(i+1), v_style);
     return v_style;
   }
 }
@@ -177,7 +177,7 @@ sdlttf_font_descent(value font)
 }
 
 ML_1(TTF_FontLineSkip, SDL_FONT, Val_int)
-#if (SDL_TTF_VERSION >= 204)
+#if (OCAMLSDL_TTF_VERSION >= 204)
 ML_1(TTF_FontFaces, SDL_FONT, Val_int)
 ML_1(TTF_FontFaceIsFixedWidth, SDL_FONT, Val_bool)
 ML_1(TTF_FontFaceFamilyName, SDL_FONT, copy_string)
@@ -187,7 +187,7 @@ Unsupported (TTF_FontFaces)
 Unsupported (TTF_FontFaceIsFixedWidth)
 Unsupported (TTF_FontFaceFamilyName)
 Unsupported (TTF_FontFaceStyleName)
-#endif /* SDL_TTF_VERSION */
+#endif /* OCAMLSDL_TTF_VERSION */
 
 CAMLprim value
 sdlttf_size_text(value font, value text)
@@ -322,3 +322,70 @@ sdlttf_glyph_metrics(value fnt, value chr)
    Store_field(result, 3, Val_int(maxy));
    return result;
 }
+
+
+/* UTF8 */
+CAMLprim value
+sdlttf_size_utf8(value font, value text)
+{
+  int w, h;
+  value v;
+  if(TTF_SizeUTF8(SDL_FONT(font), String_val(text), &w, &h))
+    sdlttf_raise_exception(TTF_GetError());
+  v = alloc_small(2, 0);
+  Field(v, 0) = Val_int(w);
+  Field(v, 1) = Val_int(h);
+  return v;
+}
+
+CAMLprim value
+sdlttf_render_utf8_solid(value font, value text, value fg) 
+{
+   SDL_Color sfg;
+   SDL_Surface *surf;
+
+   SDLColor_of_value(&sfg, fg);
+
+   surf = TTF_RenderUTF8_Solid(SDL_FONT(font),String_val(text), sfg);
+   SDL_SetColorKey(surf, SDL_SRCCOLORKEY|SDL_RLEACCEL, 0);
+   if (surf == NULL) {
+      sdlttf_raise_exception(TTF_GetError());
+   }
+   return ML_SURFACE(surf);
+}
+
+
+CAMLprim value
+sdlttf_render_utf8_shaded(value font, value text, value fg, value bg) 
+{
+   SDL_Color sfg;
+   SDL_Color sbg;
+   SDL_Surface *surf;
+
+   SDLColor_of_value(&sfg, fg);
+   SDLColor_of_value(&sbg, bg);
+
+   surf = TTF_RenderUTF8_Shaded(SDL_FONT(font),String_val(text), sfg, sbg);
+   SDL_SetColorKey(surf, SDL_SRCCOLORKEY|SDL_RLEACCEL, 0);
+   if (surf == NULL) {
+      sdlttf_raise_exception(TTF_GetError());
+   }
+   return ML_SURFACE(surf);
+}
+
+CAMLprim value
+sdlttf_render_utf8_blended(value font, value text, value fg) 
+{
+   SDL_Color sfg;
+   SDL_Surface *surf;
+
+   SDLColor_of_value(&sfg, fg);
+
+   surf = TTF_RenderUTF8_Blended(SDL_FONT(font),String_val(text), sfg);
+   SDL_SetColorKey(surf, SDL_SRCCOLORKEY|SDL_RLEACCEL, 0);
+   if (surf == NULL) {
+      sdlttf_raise_exception(TTF_GetError());
+   }
+   return ML_SURFACE(surf);
+}
+
