@@ -1,6 +1,3 @@
-#include <caml/memory.h>
-#include <caml/alloc.h>
-
 #include <SDL.h>
 
 #include "common.h"
